@@ -395,8 +395,8 @@ class Product(ModelSQL, ModelView):
                     period_id, = period_ids
                     period = period_obj.browse(period_id)
                     state_date_clause += (' AND '
-                        '(COALESCE(effective_date, planned_date) > %s)')
-                    state_date_vals.append(period.date)
+                        '(COALESCE(effective_date, planned_date, %s) > %s)')
+                    state_date_vals.extend([datetime.date.max, period.date])
                     period_vals[0] = period.id
 
         if with_childs:
